# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_carstatus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.localization.proto import localization_pb2 as modules_dot_localization_dot_proto_dot_localization__pb2
from modules.canbus.proto import chassis_detail_pb2 as modules_dot_canbus_dot_proto_dot_chassis__detail__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_carstatus.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_pb=_b('\n%modules/v2x/proto/v2x_carstatus.proto\x12\napollo.v2x\x1a-modules/localization/proto/localization.proto\x1a)modules/canbus/proto/chassis_detail.proto\"\x82\x01\n\tCarStatus\x12?\n\x0clocalization\x18\x01 \x01(\x0b\x32).apollo.localization.LocalizationEstimate\x12\x34\n\x0e\x63hassis_detail\x18\x02 \x01(\x0b\x32\x1c.apollo.canbus.ChassisDetail')
  ,
  dependencies=[modules_dot_localization_dot_proto_dot_localization__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_chassis__detail__pb2.DESCRIPTOR,])




_CARSTATUS = _descriptor.Descriptor(
  name='CarStatus',
  full_name='apollo.v2x.CarStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='localization', full_name='apollo.v2x.CarStatus.localization', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='chassis_detail', full_name='apollo.v2x.CarStatus.chassis_detail', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=274,
)

_CARSTATUS.fields_by_name['localization'].message_type = modules_dot_localization_dot_proto_dot_localization__pb2._LOCALIZATIONESTIMATE
_CARSTATUS.fields_by_name['chassis_detail'].message_type = modules_dot_canbus_dot_proto_dot_chassis__detail__pb2._CHASSISDETAIL
DESCRIPTOR.message_types_by_name['CarStatus'] = _CARSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CarStatus = _reflection.GeneratedProtocolMessageType('CarStatus', (_message.Message,), dict(
  DESCRIPTOR = _CARSTATUS,
  __module__ = 'modules.v2x.proto.v2x_carstatus_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.CarStatus)
  ))
_sym_db.RegisterMessage(CarStatus)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/camera/proto/yolo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/camera/proto/yolo.proto',
  package='apollo.perception.camera.yolo',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*modules/perception/camera/proto/yolo.proto\x12\x1d\x61pollo.perception.camera.yolo\"\xc7\x01\n\tYoloParam\x12>\n\x0bmodel_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.yolo.ModelParam\x12>\n\tnet_param\x18\x02 \x01(\x0b\x32+.apollo.perception.camera.yolo.NetworkParam\x12:\n\tnms_param\x18\x03 \x01(\x0b\x32\'.apollo.perception.camera.yolo.NMSParam\"\xc9\t\n\nModelParam\x12\x1b\n\nmodel_name\x18\x01 \x01(\t:\x07yolo-2d\x12\x1c\n\nproto_file\x18\x02 \x01(\t:\x08\x63\x61\x66\x66\x65.pt\x12 \n\x0bweight_file\x18\x03 \x01(\t:\x0b\x63\x61\x66\x66\x65.model\x12\x1b\n\tstage1_pt\x18\x15 \x01(\t:\x08\x63\x61\x66\x66\x65.pt\x12\x1e\n\tstage1_md\x18\x16 \x01(\t:\x0b\x63\x61\x66\x66\x65.model\x12\x1b\n\tstage2_pt\x18\x17 \x01(\t:\x08\x63\x61\x66\x66\x65.pt\x12\x1e\n\tstage2_md\x18\x18 \x01(\t:\x0b\x63\x61\x66\x66\x65.model\x12!\n\x0c\x61nchors_file\x18\x04 \x01(\t:\x0b\x61nchors.txt\x12\x1d\n\ntypes_file\x18\x05 \x01(\t:\ttypes.txt\x12 \n\x0c\x66\x65\x61ture_file\x18\x06 \x01(\t:\nfeature.pt\x12\x1e\n\x0coffset_ratio\x18\x07 \x01(\x02:\x08\x30.288889\x12\x1f\n\rcropped_ratio\x18\r \x01(\x02:\x08\x30.711111\x12\x1b\n\rresized_width\x18\x0e \x01(\x05:\x04\x31\x34\x34\x30\x12\x19\n\raligned_pixel\x18\x0f \x01(\x05:\x02\x33\x32\x12!\n\x14\x63onfidence_threshold\x18\x08 \x01(\x02:\x03\x30.1\x12%\n\x18light_vis_conf_threshold\x18! \x01(\x02:\x03\x30.5\x12%\n\x18light_swt_conf_threshold\x18\" \x01(\x02:\x03\x30.5\x12\x1f\n\x12roi_conf_threshold\x18\x19 \x01(\x02:\x03\x30.1\x12\x1f\n\x12\x62ox_conf_threshold\x18\x1a \x01(\x02:\x03\x30.5\x12!\n\x14stage2_nms_threshold\x18\x1b \x01(\x02:\x03\x30.4\x12\x18\n\rmin_2d_height\x18\t \x01(\x02:\x01\x30\x12\x18\n\rmin_3d_height\x18\x1e \x01(\x02:\x01\x30\x12\x17\n\x0cmin_3d_width\x18\x1f \x01(\x02:\x01\x30\x12\x18\n\rmin_3d_length\x18  \x01(\x02:\x01\x30\x12\x1f\n\x13\x63\x61libratetable_root\x18\x0b \x01(\t:\x02./\x12\x1c\n\nmodel_type\x18\x0c \x01(\t:\x08\x43\x61\x66\x66\x65Net\x12\x14\n\tori_cycle\x18\x10 \x01(\x05:\x01\x31\x12\x1a\n\x0bper_cls_reg\x18\x11 \x01(\x08:\x05\x66\x61lse\x12P\n\x14\x64imension_statistics\x18\x12 \x03(\x0b\x32\x32.apollo.perception.camera.yolo.DimensionStatistics\x12\x46\n\x0f\x62\x62ox_statistics\x18\x13 \x03(\x0b\x32-.apollo.perception.camera.yolo.BBoxStatistics\x12\x1f\n\x0b\x65xpand_file\x18\x14 \x01(\t:\nexpand.txt\x12\x19\n\nwith_box3d\x18) \x01(\x08:\x05\x66\x61lse\x12\x19\n\nwith_frbox\x18* \x01(\x08:\x05\x66\x61lse\x12\x1a\n\x0bwith_lights\x18+ \x01(\x08:\x05\x66\x61lse\x12\x1a\n\x0bwith_ratios\x18, \x01(\x08:\x05\x66\x61lse\x12\x14\n\tnum_areas\x18. \x01(\x05:\x01\x30\x12\x1a\n\x0c\x62order_ratio\x18- \x01(\x02:\x04\x30.01\"\x84\n\n\x0cNetworkParam\x12\'\n\rdet1_loc_blob\x18\x01 \x01(\t:\x10\x64\x65tect1_loc_pred\x12\'\n\rdet1_obj_blob\x18\x02 \x01(\t:\x10\x64\x65tect1_obj_pred\x12\'\n\rdet1_cls_blob\x18\x03 \x01(\t:\x10\x64\x65tect1_cls_pred\x12\'\n\rdet1_ori_blob\x18\x04 \x01(\t:\x10\x64\x65tect1_ori_pred\x12\x31\n\x12\x64\x65t1_ori_conf_blob\x18\x05 \x01(\t:\x15\x64\x65tect1_ori_conf_pred\x12\'\n\rdet1_dim_blob\x18\x06 \x01(\t:\x10\x64\x65tect1_dim_pred\x12\'\n\rdet2_loc_blob\x18\x07 \x01(\t:\x10\x64\x65tect2_loc_pred\x12\'\n\rdet2_obj_blob\x18\x08 \x01(\t:\x10\x64\x65tect2_obj_pred\x12\'\n\rdet2_cls_blob\x18\t \x01(\t:\x10\x64\x65tect2_cls_pred\x12\'\n\rdet2_ori_blob\x18\n \x01(\t:\x10\x64\x65tect2_ori_pred\x12\x31\n\x12\x64\x65t2_ori_conf_blob\x18\x0b \x01(\t:\x15\x64\x65tect2_ori_conf_pred\x12\'\n\rdet2_dim_blob\x18\x0c \x01(\t:\x10\x64\x65tect2_dim_pred\x12\'\n\rdet3_loc_blob\x18\r \x01(\t:\x10\x64\x65tect3_loc_pred\x12\'\n\rdet3_obj_blob\x18\x0e \x01(\t:\x10\x64\x65tect3_obj_pred\x12\'\n\rdet3_cls_blob\x18\x0f \x01(\t:\x10\x64\x65tect3_cls_pred\x12\'\n\rdet3_ori_blob\x18\x10 \x01(\t:\x10\x64\x65tect3_ori_pred\x12\x31\n\x12\x64\x65t3_ori_conf_blob\x18\x11 \x01(\t:\x15\x64\x65tect3_ori_conf_pred\x12\'\n\rdet3_dim_blob\x18\x12 \x01(\t:\x10\x64\x65tect3_dim_pred\x12\x1a\n\x08lof_blob\x18\x13 \x01(\t:\x08lof_pred\x12\x1a\n\x08lor_blob\x18\x14 \x01(\t:\x08lor_pred\x12\x18\n\ninput_blob\x18\x15 \x01(\t:\x04\x64\x61ta\x12\x1c\n\trois_blob\x18\x16 \x01(\t:\trois_pred\x12\x1c\n\tfeat_blob\x18\x17 \x01(\t:\tconv_feat\x12\x1a\n\x08\x62ox_blob\x18\x18 \x01(\t:\x08\x62ox_pred\x12\x1a\n\x08iou_blob\x18\x19 \x01(\t:\x08iou_pred\x12\x1e\n\nbrvis_blob\x18\x1a \x01(\t:\nbrvis_pred\x12\x1e\n\nbrswt_blob\x18\x1b \x01(\t:\nbrswt_pred\x12\x1e\n\nltvis_blob\x18\x1c \x01(\t:\nltvis_pred\x12\x1e\n\nltswt_blob\x18\x1d \x01(\t:\nltswt_pred\x12\x1e\n\nrtvis_blob\x18\x1e \x01(\t:\nrtvis_pred\x12\x1e\n\nrtswt_blob\x18\x1f \x01(\t:\nrtswt_pred\x12\"\n\x0c\x61rea_id_blob\x18  \x01(\t:\x0c\x61rea_id_pred\x12$\n\x12visible_ratio_blob\x18! \x01(\t:\x08vis_pred\x12$\n\x12\x63ut_off_ratio_blob\x18\" \x01(\t:\x08\x63ut_pred\"\x94\x01\n\x08NMSParam\x12\x17\n\x04type\x18\x01 \x01(\t:\tNormalNMS\x12\x16\n\tthreshold\x18\x02 \x01(\x02:\x03\x30.4\x12\x12\n\x05sigma\x18\x03 \x01(\x02:\x03\x30.4\x12\"\n\x15inter_cls_conf_thresh\x18\x04 \x01(\x02:\x03\x30.1\x12\x1f\n\x14inter_cls_nms_thresh\x18\x05 \x01(\x02:\x01\x31\"+\n\x0e\x42\x42oxStatistics\x12\x0c\n\x04mean\x18\x01 \x03(\x02\x12\x0b\n\x03std\x18\x02 \x03(\x02\"\x84\x01\n\x13\x44imensionStatistics\x12\x11\n\x06mean_h\x18\x01 \x01(\x02:\x01\x30\x12\x11\n\x06mean_w\x18\x02 \x01(\x02:\x01\x30\x12\x11\n\x06mean_l\x18\x03 \x01(\x02:\x01\x30\x12\x10\n\x05std_h\x18\x04 \x01(\x02:\x01\x31\x12\x10\n\x05std_w\x18\x05 \x01(\x02:\x01\x31\x12\x10\n\x05std_l\x18\x06 \x01(\x02:\x01\x31'
)




_YOLOPARAM = _descriptor.Descriptor(
  name='YoloParam',
  full_name='apollo.perception.camera.yolo.YoloParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_param', full_name='apollo.perception.camera.yolo.YoloParam.model_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='net_param', full_name='apollo.perception.camera.yolo.YoloParam.net_param', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nms_param', full_name='apollo.perception.camera.yolo.YoloParam.nms_param', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=277,
)


_MODELPARAM = _descriptor.Descriptor(
  name='ModelParam',
  full_name='apollo.perception.camera.yolo.ModelParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_name', full_name='apollo.perception.camera.yolo.ModelParam.model_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"yolo-2d".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_file', full_name='apollo.perception.camera.yolo.ModelParam.proto_file', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_file', full_name='apollo.perception.camera.yolo.ModelParam.weight_file', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.model".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage1_pt', full_name='apollo.perception.camera.yolo.ModelParam.stage1_pt', index=3,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage1_md', full_name='apollo.perception.camera.yolo.ModelParam.stage1_md', index=4,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.model".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage2_pt', full_name='apollo.perception.camera.yolo.ModelParam.stage2_pt', index=5,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage2_md', full_name='apollo.perception.camera.yolo.ModelParam.stage2_md', index=6,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"caffe.model".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anchors_file', full_name='apollo.perception.camera.yolo.ModelParam.anchors_file', index=7,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"anchors.txt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='types_file', full_name='apollo.perception.camera.yolo.ModelParam.types_file', index=8,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"types.txt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_file', full_name='apollo.perception.camera.yolo.ModelParam.feature_file', index=9,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"feature.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset_ratio', full_name='apollo.perception.camera.yolo.ModelParam.offset_ratio', index=10,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.288889),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cropped_ratio', full_name='apollo.perception.camera.yolo.ModelParam.cropped_ratio', index=11,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.711111),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resized_width', full_name='apollo.perception.camera.yolo.ModelParam.resized_width', index=12,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1440,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aligned_pixel', full_name='apollo.perception.camera.yolo.ModelParam.aligned_pixel', index=13,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=32,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence_threshold', full_name='apollo.perception.camera.yolo.ModelParam.confidence_threshold', index=14,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='light_vis_conf_threshold', full_name='apollo.perception.camera.yolo.ModelParam.light_vis_conf_threshold', index=15,
      number=33, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='light_swt_conf_threshold', full_name='apollo.perception.camera.yolo.ModelParam.light_swt_conf_threshold', index=16,
      number=34, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_conf_threshold', full_name='apollo.perception.camera.yolo.ModelParam.roi_conf_threshold', index=17,
      number=25, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box_conf_threshold', full_name='apollo.perception.camera.yolo.ModelParam.box_conf_threshold', index=18,
      number=26, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage2_nms_threshold', full_name='apollo.perception.camera.yolo.ModelParam.stage2_nms_threshold', index=19,
      number=27, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_2d_height', full_name='apollo.perception.camera.yolo.ModelParam.min_2d_height', index=20,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_3d_height', full_name='apollo.perception.camera.yolo.ModelParam.min_3d_height', index=21,
      number=30, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_3d_width', full_name='apollo.perception.camera.yolo.ModelParam.min_3d_width', index=22,
      number=31, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_3d_length', full_name='apollo.perception.camera.yolo.ModelParam.min_3d_length', index=23,
      number=32, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibratetable_root', full_name='apollo.perception.camera.yolo.ModelParam.calibratetable_root', index=24,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"./".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_type', full_name='apollo.perception.camera.yolo.ModelParam.model_type', index=25,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"CaffeNet".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ori_cycle', full_name='apollo.perception.camera.yolo.ModelParam.ori_cycle', index=26,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_cls_reg', full_name='apollo.perception.camera.yolo.ModelParam.per_cls_reg', index=27,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dimension_statistics', full_name='apollo.perception.camera.yolo.ModelParam.dimension_statistics', index=28,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bbox_statistics', full_name='apollo.perception.camera.yolo.ModelParam.bbox_statistics', index=29,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expand_file', full_name='apollo.perception.camera.yolo.ModelParam.expand_file', index=30,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"expand.txt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_box3d', full_name='apollo.perception.camera.yolo.ModelParam.with_box3d', index=31,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_frbox', full_name='apollo.perception.camera.yolo.ModelParam.with_frbox', index=32,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_lights', full_name='apollo.perception.camera.yolo.ModelParam.with_lights', index=33,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_ratios', full_name='apollo.perception.camera.yolo.ModelParam.with_ratios', index=34,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_areas', full_name='apollo.perception.camera.yolo.ModelParam.num_areas', index=35,
      number=46, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='border_ratio', full_name='apollo.perception.camera.yolo.ModelParam.border_ratio', index=36,
      number=45, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.01),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=1505,
)


_NETWORKPARAM = _descriptor.Descriptor(
  name='NetworkParam',
  full_name='apollo.perception.camera.yolo.NetworkParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='det1_loc_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_loc_blob', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_loc_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det1_obj_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_obj_blob', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_obj_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det1_cls_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_cls_blob', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_cls_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det1_ori_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_ori_blob', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_ori_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det1_ori_conf_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_ori_conf_blob', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_ori_conf_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det1_dim_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det1_dim_blob', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect1_dim_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_loc_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_loc_blob', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_loc_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_obj_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_obj_blob', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_obj_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_cls_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_cls_blob', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_cls_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_ori_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_ori_blob', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_ori_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_ori_conf_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_ori_conf_blob', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_ori_conf_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det2_dim_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det2_dim_blob', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect2_dim_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_loc_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_loc_blob', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_loc_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_obj_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_obj_blob', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_obj_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_cls_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_cls_blob', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_cls_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_ori_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_ori_blob', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_ori_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_ori_conf_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_ori_conf_blob', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_ori_conf_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='det3_dim_blob', full_name='apollo.perception.camera.yolo.NetworkParam.det3_dim_blob', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"detect3_dim_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lof_blob', full_name='apollo.perception.camera.yolo.NetworkParam.lof_blob', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"lof_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lor_blob', full_name='apollo.perception.camera.yolo.NetworkParam.lor_blob', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"lor_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_blob', full_name='apollo.perception.camera.yolo.NetworkParam.input_blob', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"data".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rois_blob', full_name='apollo.perception.camera.yolo.NetworkParam.rois_blob', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"rois_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feat_blob', full_name='apollo.perception.camera.yolo.NetworkParam.feat_blob', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"conv_feat".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box_blob', full_name='apollo.perception.camera.yolo.NetworkParam.box_blob', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"box_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iou_blob', full_name='apollo.perception.camera.yolo.NetworkParam.iou_blob', index=24,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"iou_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brvis_blob', full_name='apollo.perception.camera.yolo.NetworkParam.brvis_blob', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"brvis_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brswt_blob', full_name='apollo.perception.camera.yolo.NetworkParam.brswt_blob', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"brswt_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ltvis_blob', full_name='apollo.perception.camera.yolo.NetworkParam.ltvis_blob', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ltvis_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ltswt_blob', full_name='apollo.perception.camera.yolo.NetworkParam.ltswt_blob', index=28,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ltswt_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtvis_blob', full_name='apollo.perception.camera.yolo.NetworkParam.rtvis_blob', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"rtvis_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtswt_blob', full_name='apollo.perception.camera.yolo.NetworkParam.rtswt_blob', index=30,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"rtswt_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_id_blob', full_name='apollo.perception.camera.yolo.NetworkParam.area_id_blob', index=31,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"area_id_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible_ratio_blob', full_name='apollo.perception.camera.yolo.NetworkParam.visible_ratio_blob', index=32,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"vis_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cut_off_ratio_blob', full_name='apollo.perception.camera.yolo.NetworkParam.cut_off_ratio_blob', index=33,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"cut_pred".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1508,
  serialized_end=2792,
)


_NMSPARAM = _descriptor.Descriptor(
  name='NMSParam',
  full_name='apollo.perception.camera.yolo.NMSParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.perception.camera.yolo.NMSParam.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"NormalNMS".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='apollo.perception.camera.yolo.NMSParam.threshold', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sigma', full_name='apollo.perception.camera.yolo.NMSParam.sigma', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inter_cls_conf_thresh', full_name='apollo.perception.camera.yolo.NMSParam.inter_cls_conf_thresh', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inter_cls_nms_thresh', full_name='apollo.perception.camera.yolo.NMSParam.inter_cls_nms_thresh', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2795,
  serialized_end=2943,
)


_BBOXSTATISTICS = _descriptor.Descriptor(
  name='BBoxStatistics',
  full_name='apollo.perception.camera.yolo.BBoxStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean', full_name='apollo.perception.camera.yolo.BBoxStatistics.mean', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='std', full_name='apollo.perception.camera.yolo.BBoxStatistics.std', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2945,
  serialized_end=2988,
)


_DIMENSIONSTATISTICS = _descriptor.Descriptor(
  name='DimensionStatistics',
  full_name='apollo.perception.camera.yolo.DimensionStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean_h', full_name='apollo.perception.camera.yolo.DimensionStatistics.mean_h', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_w', full_name='apollo.perception.camera.yolo.DimensionStatistics.mean_w', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_l', full_name='apollo.perception.camera.yolo.DimensionStatistics.mean_l', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='std_h', full_name='apollo.perception.camera.yolo.DimensionStatistics.std_h', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='std_w', full_name='apollo.perception.camera.yolo.DimensionStatistics.std_w', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='std_l', full_name='apollo.perception.camera.yolo.DimensionStatistics.std_l', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2991,
  serialized_end=3123,
)

_YOLOPARAM.fields_by_name['model_param'].message_type = _MODELPARAM
_YOLOPARAM.fields_by_name['net_param'].message_type = _NETWORKPARAM
_YOLOPARAM.fields_by_name['nms_param'].message_type = _NMSPARAM
_MODELPARAM.fields_by_name['dimension_statistics'].message_type = _DIMENSIONSTATISTICS
_MODELPARAM.fields_by_name['bbox_statistics'].message_type = _BBOXSTATISTICS
DESCRIPTOR.message_types_by_name['YoloParam'] = _YOLOPARAM
DESCRIPTOR.message_types_by_name['ModelParam'] = _MODELPARAM
DESCRIPTOR.message_types_by_name['NetworkParam'] = _NETWORKPARAM
DESCRIPTOR.message_types_by_name['NMSParam'] = _NMSPARAM
DESCRIPTOR.message_types_by_name['BBoxStatistics'] = _BBOXSTATISTICS
DESCRIPTOR.message_types_by_name['DimensionStatistics'] = _DIMENSIONSTATISTICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

YoloParam = _reflection.GeneratedProtocolMessageType('YoloParam', (_message.Message,), {
  'DESCRIPTOR' : _YOLOPARAM,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.YoloParam)
  })
_sym_db.RegisterMessage(YoloParam)

ModelParam = _reflection.GeneratedProtocolMessageType('ModelParam', (_message.Message,), {
  'DESCRIPTOR' : _MODELPARAM,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.ModelParam)
  })
_sym_db.RegisterMessage(ModelParam)

NetworkParam = _reflection.GeneratedProtocolMessageType('NetworkParam', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKPARAM,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.NetworkParam)
  })
_sym_db.RegisterMessage(NetworkParam)

NMSParam = _reflection.GeneratedProtocolMessageType('NMSParam', (_message.Message,), {
  'DESCRIPTOR' : _NMSPARAM,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.NMSParam)
  })
_sym_db.RegisterMessage(NMSParam)

BBoxStatistics = _reflection.GeneratedProtocolMessageType('BBoxStatistics', (_message.Message,), {
  'DESCRIPTOR' : _BBOXSTATISTICS,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.BBoxStatistics)
  })
_sym_db.RegisterMessage(BBoxStatistics)

DimensionStatistics = _reflection.GeneratedProtocolMessageType('DimensionStatistics', (_message.Message,), {
  'DESCRIPTOR' : _DIMENSIONSTATISTICS,
  '__module__' : 'modules.perception.camera.proto.yolo_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.yolo.DimensionStatistics)
  })
_sym_db.RegisterMessage(DimensionStatistics)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/localization/proto/imu.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.localization.proto import pose_pb2 as modules_dot_localization_dot_proto_dot_pose__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/localization/proto/imu.proto',
  package='apollo.localization',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/localization/proto/imu.proto\x12\x13\x61pollo.localization\x1a!modules/common/proto/header.proto\x1a%modules/localization/proto/pose.proto\"]\n\x0c\x43orrectedImu\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12&\n\x03imu\x18\x03 \x01(\x0b\x32\x19.apollo.localization.Pose'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_localization_dot_proto_dot_pose__pb2.DESCRIPTOR,])




_CORRECTEDIMU = _descriptor.Descriptor(
  name='CorrectedImu',
  full_name='apollo.localization.CorrectedImu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.localization.CorrectedImu.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imu', full_name='apollo.localization.CorrectedImu.imu', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=228,
)

_CORRECTEDIMU.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_CORRECTEDIMU.fields_by_name['imu'].message_type = modules_dot_localization_dot_proto_dot_pose__pb2._POSE
DESCRIPTOR.message_types_by_name['CorrectedImu'] = _CORRECTEDIMU
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CorrectedImu = _reflection.GeneratedProtocolMessageType('CorrectedImu', (_message.Message,), {
  'DESCRIPTOR' : _CORRECTEDIMU,
  '__module__' : 'modules.localization.proto.imu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.localization.CorrectedImu)
  })
_sym_db.RegisterMessage(CorrectedImu)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/role_attributes.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cyber.proto import qos_profile_pb2 as cyber_dot_proto_dot_qos__profile__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/role_attributes.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!cyber/proto/role_attributes.proto\x12\x12\x61pollo.cyber.proto\x1a\x1d\x63yber/proto/qos_profile.proto\"&\n\nSocketAddr\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\"\xe0\x02\n\x0eRoleAttributes\x12\x11\n\thost_name\x18\x01 \x01(\t\x12\x0f\n\x07host_ip\x18\x02 \x01(\t\x12\x12\n\nprocess_id\x18\x03 \x01(\x05\x12\x11\n\tnode_name\x18\x04 \x01(\t\x12\x0f\n\x07node_id\x18\x05 \x01(\x04\x12\x14\n\x0c\x63hannel_name\x18\x06 \x01(\t\x12\x12\n\nchannel_id\x18\x07 \x01(\x04\x12\x14\n\x0cmessage_type\x18\x08 \x01(\t\x12\x12\n\nproto_desc\x18\t \x01(\x0c\x12\n\n\x02id\x18\n \x01(\x04\x12\x33\n\x0bqos_profile\x18\x0b \x01(\x0b\x32\x1e.apollo.cyber.proto.QosProfile\x12\x33\n\x0bsocket_addr\x18\x0c \x01(\x0b\x32\x1e.apollo.cyber.proto.SocketAddr\x12\x14\n\x0cservice_name\x18\r \x01(\t\x12\x12\n\nservice_id\x18\x0e \x01(\x04'
  ,
  dependencies=[cyber_dot_proto_dot_qos__profile__pb2.DESCRIPTOR,])




_SOCKETADDR = _descriptor.Descriptor(
  name='SocketAddr',
  full_name='apollo.cyber.proto.SocketAddr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='apollo.cyber.proto.SocketAddr.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='apollo.cyber.proto.SocketAddr.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=126,
)


_ROLEATTRIBUTES = _descriptor.Descriptor(
  name='RoleAttributes',
  full_name='apollo.cyber.proto.RoleAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_name', full_name='apollo.cyber.proto.RoleAttributes.host_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_ip', full_name='apollo.cyber.proto.RoleAttributes.host_ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_id', full_name='apollo.cyber.proto.RoleAttributes.process_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_name', full_name='apollo.cyber.proto.RoleAttributes.node_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='apollo.cyber.proto.RoleAttributes.node_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='apollo.cyber.proto.RoleAttributes.channel_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='apollo.cyber.proto.RoleAttributes.channel_id', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='apollo.cyber.proto.RoleAttributes.message_type', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_desc', full_name='apollo.cyber.proto.RoleAttributes.proto_desc', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.cyber.proto.RoleAttributes.id', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qos_profile', full_name='apollo.cyber.proto.RoleAttributes.qos_profile', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_addr', full_name='apollo.cyber.proto.RoleAttributes.socket_addr', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_name', full_name='apollo.cyber.proto.RoleAttributes.service_name', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='apollo.cyber.proto.RoleAttributes.service_id', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=481,
)

_ROLEATTRIBUTES.fields_by_name['qos_profile'].message_type = cyber_dot_proto_dot_qos__profile__pb2._QOSPROFILE
_ROLEATTRIBUTES.fields_by_name['socket_addr'].message_type = _SOCKETADDR
DESCRIPTOR.message_types_by_name['SocketAddr'] = _SOCKETADDR
DESCRIPTOR.message_types_by_name['RoleAttributes'] = _ROLEATTRIBUTES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SocketAddr = _reflection.GeneratedProtocolMessageType('SocketAddr', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETADDR,
  '__module__' : 'cyber.proto.role_attributes_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.SocketAddr)
  })
_sym_db.RegisterMessage(SocketAddr)

RoleAttributes = _reflection.GeneratedProtocolMessageType('RoleAttributes', (_message.Message,), {
  'DESCRIPTOR' : _ROLEATTRIBUTES,
  '__module__' : 'cyber.proto.role_attributes_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.RoleAttributes)
  })
_sym_db.RegisterMessage(RoleAttributes)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/dst_type_fusion_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/dst_type_fusion_config.proto',
  package='apollo.perception.fusion',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5modules/perception/proto/dst_type_fusion_config.proto\x12\x18\x61pollo.perception.fusion\"}\n\x18\x43\x61meraDstTypeFusionParam\x12\x0e\n\x04name\x18\x01 \x01(\t:\x00\x12\x15\n\nvalid_dist\x18\x02 \x01(\x01:\x01\x30\x12\x16\n\x0breliability\x18\x03 \x01(\x01:\x01\x30\x12\"\n\x17reliability_for_unknown\x18\x04 \x01(\x01:\x01\x30\"e\n\x17LidarDstTypeFusionParam\x12\x0e\n\x04name\x18\x01 \x01(\t:\x00\x12\x16\n\x0breliability\x18\x02 \x01(\x01:\x01\x30\x12\"\n\x17reliability_for_unknown\x18\x03 \x01(\x01:\x01\x30\"\xa9\x01\n\x13\x44stTypeFusionConfig\x12I\n\rcamera_params\x18\x01 \x03(\x0b\x32\x32.apollo.perception.fusion.CameraDstTypeFusionParam\x12G\n\x0clidar_params\x18\x02 \x03(\x0b\x32\x31.apollo.perception.fusion.LidarDstTypeFusionParam'
)




_CAMERADSTTYPEFUSIONPARAM = _descriptor.Descriptor(
  name='CameraDstTypeFusionParam',
  full_name='apollo.perception.fusion.CameraDstTypeFusionParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.fusion.CameraDstTypeFusionParam.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid_dist', full_name='apollo.perception.fusion.CameraDstTypeFusionParam.valid_dist', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reliability', full_name='apollo.perception.fusion.CameraDstTypeFusionParam.reliability', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reliability_for_unknown', full_name='apollo.perception.fusion.CameraDstTypeFusionParam.reliability_for_unknown', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=208,
)


_LIDARDSTTYPEFUSIONPARAM = _descriptor.Descriptor(
  name='LidarDstTypeFusionParam',
  full_name='apollo.perception.fusion.LidarDstTypeFusionParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.fusion.LidarDstTypeFusionParam.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reliability', full_name='apollo.perception.fusion.LidarDstTypeFusionParam.reliability', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reliability_for_unknown', full_name='apollo.perception.fusion.LidarDstTypeFusionParam.reliability_for_unknown', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=311,
)


_DSTTYPEFUSIONCONFIG = _descriptor.Descriptor(
  name='DstTypeFusionConfig',
  full_name='apollo.perception.fusion.DstTypeFusionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_params', full_name='apollo.perception.fusion.DstTypeFusionConfig.camera_params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lidar_params', full_name='apollo.perception.fusion.DstTypeFusionConfig.lidar_params', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=483,
)

_DSTTYPEFUSIONCONFIG.fields_by_name['camera_params'].message_type = _CAMERADSTTYPEFUSIONPARAM
_DSTTYPEFUSIONCONFIG.fields_by_name['lidar_params'].message_type = _LIDARDSTTYPEFUSIONPARAM
DESCRIPTOR.message_types_by_name['CameraDstTypeFusionParam'] = _CAMERADSTTYPEFUSIONPARAM
DESCRIPTOR.message_types_by_name['LidarDstTypeFusionParam'] = _LIDARDSTTYPEFUSIONPARAM
DESCRIPTOR.message_types_by_name['DstTypeFusionConfig'] = _DSTTYPEFUSIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CameraDstTypeFusionParam = _reflection.GeneratedProtocolMessageType('CameraDstTypeFusionParam', (_message.Message,), {
  'DESCRIPTOR' : _CAMERADSTTYPEFUSIONPARAM,
  '__module__' : 'modules.perception.proto.dst_type_fusion_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.fusion.CameraDstTypeFusionParam)
  })
_sym_db.RegisterMessage(CameraDstTypeFusionParam)

LidarDstTypeFusionParam = _reflection.GeneratedProtocolMessageType('LidarDstTypeFusionParam', (_message.Message,), {
  'DESCRIPTOR' : _LIDARDSTTYPEFUSIONPARAM,
  '__module__' : 'modules.perception.proto.dst_type_fusion_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.fusion.LidarDstTypeFusionParam)
  })
_sym_db.RegisterMessage(LidarDstTypeFusionParam)

DstTypeFusionConfig = _reflection.GeneratedProtocolMessageType('DstTypeFusionConfig', (_message.Message,), {
  'DESCRIPTOR' : _DSTTYPEFUSIONCONFIG,
  '__module__' : 'modules.perception.proto.dst_type_fusion_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.fusion.DstTypeFusionConfig)
  })
_sym_db.RegisterMessage(DstTypeFusionConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/proto/drive_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/proto/drive_state.proto',
  package='apollo.common',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/common/proto/drive_state.proto\x12\rapollo.common\"\xcd\x01\n\x0c\x45ngageAdvice\x12\x43\n\x06\x61\x64vice\x18\x01 \x01(\x0e\x32\".apollo.common.EngageAdvice.Advice:\x0f\x44ISALLOW_ENGAGE\x12\x0e\n\x06reason\x18\x02 \x01(\t\"h\n\x06\x41\x64vice\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0f\x44ISALLOW_ENGAGE\x10\x01\x12\x13\n\x0fREADY_TO_ENGAGE\x10\x02\x12\x10\n\x0cKEEP_ENGAGED\x10\x03\x12\x15\n\x11PREPARE_DISENGAGE\x10\x04'
)



_ENGAGEADVICE_ADVICE = _descriptor.EnumDescriptor(
  name='Advice',
  full_name='apollo.common.EngageAdvice.Advice',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISALLOW_ENGAGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY_TO_ENGAGE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KEEP_ENGAGED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREPARE_DISENGAGE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=159,
  serialized_end=263,
)
_sym_db.RegisterEnumDescriptor(_ENGAGEADVICE_ADVICE)


_ENGAGEADVICE = _descriptor.Descriptor(
  name='EngageAdvice',
  full_name='apollo.common.EngageAdvice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='advice', full_name='apollo.common.EngageAdvice.advice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='apollo.common.EngageAdvice.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ENGAGEADVICE_ADVICE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=263,
)

_ENGAGEADVICE.fields_by_name['advice'].enum_type = _ENGAGEADVICE_ADVICE
_ENGAGEADVICE_ADVICE.containing_type = _ENGAGEADVICE
DESCRIPTOR.message_types_by_name['EngageAdvice'] = _ENGAGEADVICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EngageAdvice = _reflection.GeneratedProtocolMessageType('EngageAdvice', (_message.Message,), {
  'DESCRIPTOR' : _ENGAGEADVICE,
  '__module__' : 'modules.common.proto.drive_state_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.EngageAdvice)
  })
_sym_db.RegisterMessage(EngageAdvice)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/dst_existence_fusion_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/dst_existence_fusion_config.proto',
  package='apollo.perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:modules/perception/proto/dst_existence_fusion_config.proto\x12\x11\x61pollo.perception\"?\n\x0f\x43\x61meraValidDist\x12\x15\n\x0b\x63\x61mera_name\x18\x01 \x01(\t:\x00\x12\x15\n\nvalid_dist\x18\x02 \x01(\x01:\x01\x30\"\x85\x01\n\x18\x44stExistenceFusionConfig\x12*\n\x1ftrack_object_max_match_distance\x18\x01 \x01(\x01:\x01\x34\x12=\n\x11\x63\x61mera_valid_dist\x18\x02 \x03(\x0b\x32\".apollo.perception.CameraValidDist'
)




_CAMERAVALIDDIST = _descriptor.Descriptor(
  name='CameraValidDist',
  full_name='apollo.perception.CameraValidDist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_name', full_name='apollo.perception.CameraValidDist.camera_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid_dist', full_name='apollo.perception.CameraValidDist.valid_dist', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=144,
)


_DSTEXISTENCEFUSIONCONFIG = _descriptor.Descriptor(
  name='DstExistenceFusionConfig',
  full_name='apollo.perception.DstExistenceFusionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='track_object_max_match_distance', full_name='apollo.perception.DstExistenceFusionConfig.track_object_max_match_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_valid_dist', full_name='apollo.perception.DstExistenceFusionConfig.camera_valid_dist', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=280,
)

_DSTEXISTENCEFUSIONCONFIG.fields_by_name['camera_valid_dist'].message_type = _CAMERAVALIDDIST
DESCRIPTOR.message_types_by_name['CameraValidDist'] = _CAMERAVALIDDIST
DESCRIPTOR.message_types_by_name['DstExistenceFusionConfig'] = _DSTEXISTENCEFUSIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CameraValidDist = _reflection.GeneratedProtocolMessageType('CameraValidDist', (_message.Message,), {
  'DESCRIPTOR' : _CAMERAVALIDDIST,
  '__module__' : 'modules.perception.proto.dst_existence_fusion_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.CameraValidDist)
  })
_sym_db.RegisterMessage(CameraValidDist)

DstExistenceFusionConfig = _reflection.GeneratedProtocolMessageType('DstExistenceFusionConfig', (_message.Message,), {
  'DESCRIPTOR' : _DSTEXISTENCEFUSIONCONFIG,
  '__module__' : 'modules.perception.proto.dst_existence_fusion_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.DstExistenceFusionConfig)
  })
_sym_db.RegisterMessage(DstExistenceFusionConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/contrib/lgsvl_msgs/proto/detection3d.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.contrib.lgsvl_msgs.proto import detection2d_pb2 as modules_dot_contrib_dot_lgsvl__msgs_dot_proto_dot_detection2d__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/contrib/lgsvl_msgs/proto/detection3d.proto',
  package='apollo.contrib.lgsvl_msgs',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2modules/contrib/lgsvl_msgs/proto/detection3d.proto\x12\x19\x61pollo.contrib.lgsvl_msgs\x1a!modules/common/proto/header.proto\x1a#modules/common/proto/geometry.proto\x1a\x32modules/contrib/lgsvl_msgs/proto/detection2d.proto\"`\n\x04Pose\x12(\n\x08position\x18\x01 \x01(\x0b\x32\x16.apollo.common.Point3D\x12.\n\x0borientation\x18\x02 \x01(\x0b\x32\x19.apollo.common.Quaternion\"t\n\rBoundingBox3D\x12\x31\n\x08position\x18\x01 \x01(\x0b\x32\x1f.apollo.contrib.lgsvl_msgs.Pose\x12\x30\n\x04size\x18\x02 \x01(\x0b\x32\".apollo.contrib.lgsvl_msgs.Vector3\"\xca\x01\n\x0b\x44\x65tection3D\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\n\n\x02id\x18\x02 \x01(\r\x12\r\n\x05label\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x01\x12\x36\n\x04\x62\x62ox\x18\x05 \x01(\x0b\x32(.apollo.contrib.lgsvl_msgs.BoundingBox3D\x12\x32\n\x08velocity\x18\x06 \x01(\x0b\x32 .apollo.contrib.lgsvl_msgs.Twistb\x06proto3'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_contrib_dot_lgsvl__msgs_dot_proto_dot_detection2d__pb2.DESCRIPTOR,])




_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='apollo.contrib.lgsvl_msgs.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.contrib.lgsvl_msgs.Pose.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='apollo.contrib.lgsvl_msgs.Pose.orientation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=301,
)


_BOUNDINGBOX3D = _descriptor.Descriptor(
  name='BoundingBox3D',
  full_name='apollo.contrib.lgsvl_msgs.BoundingBox3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.contrib.lgsvl_msgs.BoundingBox3D.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='apollo.contrib.lgsvl_msgs.BoundingBox3D.size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=419,
)


_DETECTION3D = _descriptor.Descriptor(
  name='Detection3D',
  full_name='apollo.contrib.lgsvl_msgs.Detection3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.contrib.lgsvl_msgs.Detection3D.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.contrib.lgsvl_msgs.Detection3D.id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='apollo.contrib.lgsvl_msgs.Detection3D.label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='apollo.contrib.lgsvl_msgs.Detection3D.score', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bbox', full_name='apollo.contrib.lgsvl_msgs.Detection3D.bbox', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='apollo.contrib.lgsvl_msgs.Detection3D.velocity', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=422,
  serialized_end=624,
)

_POSE.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_POSE.fields_by_name['orientation'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._QUATERNION
_BOUNDINGBOX3D.fields_by_name['position'].message_type = _POSE
_BOUNDINGBOX3D.fields_by_name['size'].message_type = modules_dot_contrib_dot_lgsvl__msgs_dot_proto_dot_detection2d__pb2._VECTOR3
_DETECTION3D.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_DETECTION3D.fields_by_name['bbox'].message_type = _BOUNDINGBOX3D
_DETECTION3D.fields_by_name['velocity'].message_type = modules_dot_contrib_dot_lgsvl__msgs_dot_proto_dot_detection2d__pb2._TWIST
DESCRIPTOR.message_types_by_name['Pose'] = _POSE
DESCRIPTOR.message_types_by_name['BoundingBox3D'] = _BOUNDINGBOX3D
DESCRIPTOR.message_types_by_name['Detection3D'] = _DETECTION3D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pose = _reflection.GeneratedProtocolMessageType('Pose', (_message.Message,), {
  'DESCRIPTOR' : _POSE,
  '__module__' : 'modules.contrib.lgsvl_msgs.proto.detection3d_pb2'
  # @@protoc_insertion_point(class_scope:apollo.contrib.lgsvl_msgs.Pose)
  })
_sym_db.RegisterMessage(Pose)

BoundingBox3D = _reflection.GeneratedProtocolMessageType('BoundingBox3D', (_message.Message,), {
  'DESCRIPTOR' : _BOUNDINGBOX3D,
  '__module__' : 'modules.contrib.lgsvl_msgs.proto.detection3d_pb2'
  # @@protoc_insertion_point(class_scope:apollo.contrib.lgsvl_msgs.BoundingBox3D)
  })
_sym_db.RegisterMessage(BoundingBox3D)

Detection3D = _reflection.GeneratedProtocolMessageType('Detection3D', (_message.Message,), {
  'DESCRIPTOR' : _DETECTION3D,
  '__module__' : 'modules.contrib.lgsvl_msgs.proto.detection3d_pb2'
  # @@protoc_insertion_point(class_scope:apollo.contrib.lgsvl_msgs.Detection3D)
  })
_sym_db.RegisterMessage(Detection3D)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/routing/proto/routing_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/routing/proto/routing_config.proto',
  package='apollo.routing',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*modules/routing/proto/routing_config.proto\x12\x0e\x61pollo.routing\"U\n\x0bTopicConfig\x12\x1e\n\x16routing_response_topic\x18\x01 \x01(\t\x12&\n\x1erouting_response_history_topic\x18\x02 \x01(\t\"\xda\x01\n\rRoutingConfig\x12\x12\n\nbase_speed\x18\x01 \x01(\x01\x12\x19\n\x11left_turn_penalty\x18\x02 \x01(\x01\x12\x1a\n\x12right_turn_penalty\x18\x03 \x01(\x01\x12\x15\n\ruturn_penalty\x18\x04 \x01(\x01\x12\x16\n\x0e\x63hange_penalty\x18\x05 \x01(\x01\x12\x1c\n\x14\x62\x61se_changing_length\x18\x06 \x01(\x01\x12\x31\n\x0ctopic_config\x18\x07 \x01(\x0b\x32\x1b.apollo.routing.TopicConfig'
)




_TOPICCONFIG = _descriptor.Descriptor(
  name='TopicConfig',
  full_name='apollo.routing.TopicConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing_response_topic', full_name='apollo.routing.TopicConfig.routing_response_topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_response_history_topic', full_name='apollo.routing.TopicConfig.routing_response_history_topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=147,
)


_ROUTINGCONFIG = _descriptor.Descriptor(
  name='RoutingConfig',
  full_name='apollo.routing.RoutingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_speed', full_name='apollo.routing.RoutingConfig.base_speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_turn_penalty', full_name='apollo.routing.RoutingConfig.left_turn_penalty', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_turn_penalty', full_name='apollo.routing.RoutingConfig.right_turn_penalty', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uturn_penalty', full_name='apollo.routing.RoutingConfig.uturn_penalty', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_penalty', full_name='apollo.routing.RoutingConfig.change_penalty', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_changing_length', full_name='apollo.routing.RoutingConfig.base_changing_length', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_config', full_name='apollo.routing.RoutingConfig.topic_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=368,
)

_ROUTINGCONFIG.fields_by_name['topic_config'].message_type = _TOPICCONFIG
DESCRIPTOR.message_types_by_name['TopicConfig'] = _TOPICCONFIG
DESCRIPTOR.message_types_by_name['RoutingConfig'] = _ROUTINGCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicConfig = _reflection.GeneratedProtocolMessageType('TopicConfig', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCONFIG,
  '__module__' : 'modules.routing.proto.routing_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.TopicConfig)
  })
_sym_db.RegisterMessage(TopicConfig)

RoutingConfig = _reflection.GeneratedProtocolMessageType('RoutingConfig', (_message.Message,), {
  'DESCRIPTOR' : _ROUTINGCONFIG,
  '__module__' : 'modules.routing.proto.routing_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.routing.RoutingConfig)
  })
_sym_db.RegisterMessage(RoutingConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/proto/data_collection_table.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/proto/data_collection_table.proto',
  package='apollo.dreamview',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3modules/dreamview/proto/data_collection_table.proto\x12\x10\x61pollo.dreamview\"\x84\x01\n\tCriterion\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x41\n\x13\x63omparison_operator\x18\x02 \x01(\x0e\x32$.apollo.dreamview.ComparisonOperator\x12\r\n\x05value\x18\x03 \x01(\x02\x12\x16\n\x0evehicle_config\x18\x04 \x01(\t\"E\n\x05Range\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\tcriterion\x18\x02 \x03(\x0b\x32\x1b.apollo.dreamview.Criterion\"?\n\x07\x46\x65\x61ture\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x05range\x18\x02 \x03(\x0b\x32\x17.apollo.dreamview.Range\"6\n\x08Scenario\x12*\n\x07\x66\x65\x61ture\x18\x01 \x03(\x0b\x32\x19.apollo.dreamview.Feature\"\xd8\x01\n\x13\x44\x61taCollectionTable\x12\x45\n\x08scenario\x18\x01 \x03(\x0b\x32\x33.apollo.dreamview.DataCollectionTable.ScenarioEntry\x12\x17\n\x0f\x66rame_threshold\x18\x02 \x02(\r\x12\x14\n\x0ctotal_frames\x18\x03 \x02(\r\x1aK\n\rScenarioEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.apollo.dreamview.Scenario:\x02\x38\x01*\x82\x01\n\x12\x43omparisonOperator\x12\t\n\x05\x45QUAL\x10\x00\x12\r\n\tNOT_EQUAL\x10\x01\x12\x10\n\x0cGREATER_THAN\x10\x02\x12\x19\n\x15GREATER_THAN_OR_EQUAL\x10\x03\x12\r\n\tLESS_THAN\x10\x04\x12\x16\n\x12LESS_THAN_OR_EQUAL\x10\x05'
)

_COMPARISONOPERATOR = _descriptor.EnumDescriptor(
  name='ComparisonOperator',
  full_name='apollo.dreamview.ComparisonOperator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_OR_EQUAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_OR_EQUAL', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=620,
  serialized_end=750,
)
_sym_db.RegisterEnumDescriptor(_COMPARISONOPERATOR)

ComparisonOperator = enum_type_wrapper.EnumTypeWrapper(_COMPARISONOPERATOR)
EQUAL = 0
NOT_EQUAL = 1
GREATER_THAN = 2
GREATER_THAN_OR_EQUAL = 3
LESS_THAN = 4
LESS_THAN_OR_EQUAL = 5



_CRITERION = _descriptor.Descriptor(
  name='Criterion',
  full_name='apollo.dreamview.Criterion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='apollo.dreamview.Criterion.field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comparison_operator', full_name='apollo.dreamview.Criterion.comparison_operator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.Criterion.value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_config', full_name='apollo.dreamview.Criterion.vehicle_config', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=206,
)


_RANGE = _descriptor.Descriptor(
  name='Range',
  full_name='apollo.dreamview.Range',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.dreamview.Range.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='criterion', full_name='apollo.dreamview.Range.criterion', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=277,
)


_FEATURE = _descriptor.Descriptor(
  name='Feature',
  full_name='apollo.dreamview.Feature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.dreamview.Feature.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range', full_name='apollo.dreamview.Feature.range', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=342,
)


_SCENARIO = _descriptor.Descriptor(
  name='Scenario',
  full_name='apollo.dreamview.Scenario',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature', full_name='apollo.dreamview.Scenario.feature', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=398,
)


_DATACOLLECTIONTABLE_SCENARIOENTRY = _descriptor.Descriptor(
  name='ScenarioEntry',
  full_name='apollo.dreamview.DataCollectionTable.ScenarioEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.DataCollectionTable.ScenarioEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.DataCollectionTable.ScenarioEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=542,
  serialized_end=617,
)

_DATACOLLECTIONTABLE = _descriptor.Descriptor(
  name='DataCollectionTable',
  full_name='apollo.dreamview.DataCollectionTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scenario', full_name='apollo.dreamview.DataCollectionTable.scenario', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_threshold', full_name='apollo.dreamview.DataCollectionTable.frame_threshold', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_frames', full_name='apollo.dreamview.DataCollectionTable.total_frames', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATACOLLECTIONTABLE_SCENARIOENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=617,
)

_CRITERION.fields_by_name['comparison_operator'].enum_type = _COMPARISONOPERATOR
_RANGE.fields_by_name['criterion'].message_type = _CRITERION
_FEATURE.fields_by_name['range'].message_type = _RANGE
_SCENARIO.fields_by_name['feature'].message_type = _FEATURE
_DATACOLLECTIONTABLE_SCENARIOENTRY.fields_by_name['value'].message_type = _SCENARIO
_DATACOLLECTIONTABLE_SCENARIOENTRY.containing_type = _DATACOLLECTIONTABLE
_DATACOLLECTIONTABLE.fields_by_name['scenario'].message_type = _DATACOLLECTIONTABLE_SCENARIOENTRY
DESCRIPTOR.message_types_by_name['Criterion'] = _CRITERION
DESCRIPTOR.message_types_by_name['Range'] = _RANGE
DESCRIPTOR.message_types_by_name['Feature'] = _FEATURE
DESCRIPTOR.message_types_by_name['Scenario'] = _SCENARIO
DESCRIPTOR.message_types_by_name['DataCollectionTable'] = _DATACOLLECTIONTABLE
DESCRIPTOR.enum_types_by_name['ComparisonOperator'] = _COMPARISONOPERATOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Criterion = _reflection.GeneratedProtocolMessageType('Criterion', (_message.Message,), {
  'DESCRIPTOR' : _CRITERION,
  '__module__' : 'modules.dreamview.proto.data_collection_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Criterion)
  })
_sym_db.RegisterMessage(Criterion)

Range = _reflection.GeneratedProtocolMessageType('Range', (_message.Message,), {
  'DESCRIPTOR' : _RANGE,
  '__module__' : 'modules.dreamview.proto.data_collection_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Range)
  })
_sym_db.RegisterMessage(Range)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {
  'DESCRIPTOR' : _FEATURE,
  '__module__' : 'modules.dreamview.proto.data_collection_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Feature)
  })
_sym_db.RegisterMessage(Feature)

Scenario = _reflection.GeneratedProtocolMessageType('Scenario', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIO,
  '__module__' : 'modules.dreamview.proto.data_collection_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Scenario)
  })
_sym_db.RegisterMessage(Scenario)

DataCollectionTable = _reflection.GeneratedProtocolMessageType('DataCollectionTable', (_message.Message,), {

  'ScenarioEntry' : _reflection.GeneratedProtocolMessageType('ScenarioEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATACOLLECTIONTABLE_SCENARIOENTRY,
    '__module__' : 'modules.dreamview.proto.data_collection_table_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.DataCollectionTable.ScenarioEntry)
    })
  ,
  'DESCRIPTOR' : _DATACOLLECTIONTABLE,
  '__module__' : 'modules.dreamview.proto.data_collection_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.DataCollectionTable)
  })
_sym_db.RegisterMessage(DataCollectionTable)
_sym_db.RegisterMessage(DataCollectionTable.ScenarioEntry)


_DATACOLLECTIONTABLE_SCENARIOENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/map_manager_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/map_manager_config.proto',
  package='apollo.perception.lidar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1modules/perception/proto/map_manager_config.proto\x12\x17\x61pollo.perception.lidar\"v\n\x10MapManagerConfig\x12\x1a\n\x0bupdate_pose\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x13roi_search_distance\x18\x02 \x01(\x01:\x02\x38\x30\x12\x12\n\nlane_range\x18\x03 \x01(\x01\x12\x11\n\tmax_depth\x18\x04 \x01(\x01'
)




_MAPMANAGERCONFIG = _descriptor.Descriptor(
  name='MapManagerConfig',
  full_name='apollo.perception.lidar.MapManagerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_pose', full_name='apollo.perception.lidar.MapManagerConfig.update_pose', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roi_search_distance', full_name='apollo.perception.lidar.MapManagerConfig.roi_search_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(80),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_range', full_name='apollo.perception.lidar.MapManagerConfig.lane_range', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_depth', full_name='apollo.perception.lidar.MapManagerConfig.max_depth', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=196,
)

DESCRIPTOR.message_types_by_name['MapManagerConfig'] = _MAPMANAGERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MapManagerConfig = _reflection.GeneratedProtocolMessageType('MapManagerConfig', (_message.Message,), {
  'DESCRIPTOR' : _MAPMANAGERCONFIG,
  '__module__' : 'modules.perception.proto.map_manager_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.lidar.MapManagerConfig)
  })
_sym_db.RegisterMessage(MapManagerConfig)


# @@protoc_insertion_point(module_scope)
